# Introduction

> As the actual experience, we find that MCP Server works for Agent is better than a single chat model. We try to each of Agent we can find out even developed agents with different sdk, therefore we find out the best way to use Stata-MCP in an Agent at present.

In this section, we will introduce the basic usage of Claude Code with Stata-MCP. All the example is using macOS with Apple Silicon, if you are a windows user, you can copy this page to ChatGPT and ask for help.

## Quickly Start
### Install Stata-MCP
Install Stata-MCP in Claude Code is easy:
```bash
claude mcp add stata-mcp uvx stata-mcp
```

### Let Claude use Stata-MCP
After boot Claude Code, you can talk to it like this:
```markdown
> Load the default data of stata, and analyze the data. Export the summarization of the data into a '.docx' file.
```

